"use client";

import React, { useState, useEffect } from 'react';
import { Card, Table, Space, Tag, Form, Select, DatePicker, Input, Button } from 'antd';
import { SearchOutlined, ReloadOutlined } from '@ant-design/icons';
import dayjs from 'dayjs';
import { api } from '@nice/client';

const { RangePicker } = DatePicker;
const { Option } = Select;

// 日志接口定义
interface ILog {
  id: string;
  timestamp: string;
  level: string;
  module: string;
  action: string;
  operatorId?: string;
  operator?: {
    id: string;
    username: string;
    showname?: string;
  };
  ipAddress?: string;
  targetId?: string;
  targetType?: string;
  targetName?: string;
  details?: any;
  beforeData?: any;
  afterData?: any;
  status: string;
  errorMessage?: string;
}

// 添加日志的函数
export const addLog = async (logData: Omit<ILog, 'id' | 'timestamp'>) => {
  try {
    // 使用tRPC发送日志
    const result = await api.systemLog.create.mutate({
      ...logData,
      level: logData.level || 'info',
      status: logData.status || 'success',
    });
    
    console.log('日志已写入数据库:', result);
    return true;
  } catch (error) {
    console.error('写入日志失败:', error);
    // 可以考虑添加本地缓存逻辑
    return false;
  }
};

// 用于添加人员操作日志的便捷方法
export const addStaffLog = async (
  action: string,
  targetId: string,
  targetName: string,
  beforeData: any = null,
  afterData: any = null,
  status: 'success' | 'failure' = 'success',
  errorMessage?: string
) => {
  return api.systemLog.logStaffAction.mutate({
    action,
    targetId,
    targetName,
    beforeData,
    afterData,
    status,
    errorMessage
  });
};

const SystemLogPage = () => {
  const [form] = Form.useForm();
  const [queryParams, setQueryParams] = useState({
    page: 1,
    pageSize: 10,
  });
  
  // 使用tRPC查询日志
  const { data, isLoading, refetch } = api.systemLog.getLogs.useQuery({ 
    page: queryParams.page, 
    pageSize: queryParams.pageSize 
  });
  
  // 处理表格分页变化
  const handleTableChange = (pagination: any) => {
    setQueryParams({
      ...queryParams,
      page: pagination.current,
      pageSize: pagination.pageSize,
    });
  };
  
  // 处理表单查询
  const handleSearch = (values: any) => {
    const { timeRange, ...rest } = values;
    
    const params: any = {
      ...rest,
      page: 1, // 重置到第一页
      pageSize: queryParams.pageSize,
    };
    
    // 处理时间范围
    if (timeRange && timeRange.length === 2) {
      params.startTime = timeRange[0].startOf('day').toISOString();
      params.endTime = timeRange[1].endOf('day').toISOString();
    }
    
    setQueryParams(params);
  };
  
  // 格式化时间显示
  const formatTime = (timeStr: string) => {
    return dayjs(timeStr).format('YYYY-MM-DD HH:mm:ss');
  };
  
  // 表格列定义
  const columns = [
    {
      title: '操作时间',
      dataIndex: 'timestamp',
      key: 'timestamp',
      render: (text: string) => formatTime(text)
    },
    {
      title: '级别',
      dataIndex: 'level',
      key: 'level',
      render: (text: string) => (
        <Tag color={
          text === 'info' ? 'blue' :
          text === 'warning' ? 'orange' :
          text === 'error' ? 'red' : 'green'
        }>
          {text.toUpperCase()}
        </Tag>
      )
    },
    {
      title: '模块',
      dataIndex: 'module',
      key: 'module',
    },
    {
      title: '操作',
      dataIndex: 'action',
      key: 'action',
    },
    {
      title: '操作人',
      key: 'operator',
      render: (_, record: ILog) => (
        record.operator ? record.operator.showname || record.operator.username : '-'
      )
    },
    {
      title: '操作对象',
      dataIndex: 'targetName',
      key: 'targetName',
      render: (text: string) => text || '-'
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      render: (text: string) => (
        <Tag color={text === 'success' ? 'green' : 'red'}>
          {text === 'success' ? '成功' : '失败'}
        </Tag>
      )
    },
  ];
  
  return (
    <div className="space-y-4">
      <Card>
        <Form 
          form={form} 
          layout="vertical" 
          onFinish={handleSearch}
          className="mb-4"
        >
          <div className="grid grid-cols-1 md:grid-cols-4 gap-4">
            <Form.Item name="keyword" label="关键词">
              <Input placeholder="请输入关键词" allowClear />
            </Form.Item>
            
            <Form.Item name="level" label="日志级别">
              <Select placeholder="请选择级别" allowClear>
                <Option value="info">信息</Option>
                <Option value="warning">警告</Option>
                <Option value="error">错误</Option>
                <Option value="debug">调试</Option>
              </Select>
            </Form.Item>
            
            <Form.Item name="status" label="状态">
              <Select placeholder="请选择状态" allowClear>
                <Option value="success">成功</Option>
                <Option value="failure">失败</Option>
              </Select>
            </Form.Item>
            
            <Form.Item name="timeRange" label="时间范围">
              <RangePicker className="w-full" />
            </Form.Item>
          </div>
          
          <div className="flex justify-end">
            <Space>
              <Button onClick={() => form.resetFields()}>重置</Button>
              <Button type="primary" htmlType="submit" icon={<SearchOutlined />}>
                查询
              </Button>
              <Button icon={<ReloadOutlined />} onClick={() => refetch()}>
                刷新
              </Button>
            </Space>
          </div>
        </Form>
      </Card>
      
      <Card>
        <Table
          columns={columns}
          dataSource={data?.items || []}
          rowKey="id"
          pagination={{
            current: data?.pagination?.current || 1,
            pageSize: data?.pagination?.pageSize || 10,
            total: data?.pagination?.total || 0,
            showSizeChanger: true,
            showQuickJumper: true,
            showTotal: (total) => `共 ${total} 条日志`
          }}
          loading={isLoading}
          onChange={handleTableChange}
        />
      </Card>
    </div>
  );
};

export default SystemLogPage;